System requirements — Scrapple documentation

### Navigation

- index
- modules |
- next |
- previous |
- Scrapple documentation »

# System requirements

Scrapple is a Python package/command line tool which runs on all operating systems that support Python. This includes :

- Windows XP
- Windows Vista
- Windows 7
- Windows 8.x
- Common Linux distros : Ubuntu/Xubuntu/Lubuntu, Fedora, Mint, Gentoo, openSUSE, Arch Linux etc.
- OS X

The basic requirements for running Scrapple are:

- Python 2.7 or 3.x
- pip or easy_install for installing the necessary Python packages [pip is the recommended choice]

Scrapple depends on a number of Python packages for various parts of its execution :

- requests : The HTTP library. The requests library is used to make HTTP requests to load the required web pages.
- lxml : The web scraping library. The lxml library is used to parse the element tree and extract the required content.
- cssselect : The CSS selector library. cssselect works in tandem with lxml to handle CSS Selector expressions.
- docopt : The command line parser. The docopt library is used to parse the command line interface input based on the CLI usage specification in the docstring.
- Jinja2 : The templating engine. Jinja2 is used to create skeleton configuration file and generated Python scraper scripts.
- Flask : The web micro-framework. The web interface to edit configuration files runs on Flask.
- colorama : The output formatter. colorama is used to format the various sections of the command line output.

### Navigation

- index
- modules |
- next |
- previous |
- Scrapple documentation »